==> asm-8.5.4-en-download.zip: asm-8.5.4-en/webhelp/asm-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasparallelservices
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasparallelservices = {
    baseurls: ["../"],
    varname: "adabasparallelservices",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Release Notes",
              tree: [
                  { url: "relnotes/enh.htm", title: "Enhancements" },
                  { url: "relnotes/addons.htm", title: "Adabas Product Support" },
                  { url: "relnotes/restsup.htm", title: "Restricted Support for Adabas Features" },
                  { url: "relnotes/mig_asm.htm", title: "Migrating from Prior Versions" },
                  { url: "relnotes/zaps.htm", title: "Zap Information" },
                  { url: "relnotes/eom.htm", title: "End of Maintenance" },
                  { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
              ]
            },
            { url: "install/asmiov.htm", title: "Installation",
              tree: [
                  { url: "install/asmiconv.htm", title: "Conventions" },
                  { url: "install/sysreq.htm", title: "System Requirements" },
                  { url: "install/asmisma.htm", title: "Using System Maintenance Aid" },
                  { url: "install/asmids.htm", title: "Data Sets Delivered" },
                  { url: "install/asmios.htm", title: "z/OS Systems Installation" },
                  { url: "install/proc_csa.htm", title: "Modifying the z/OS Common Storage (CSA) Key" },
              ]
            },
            { url: "intro/asmcov.htm", title: "Concepts and Facilities",
              tree: [
                  { url: "intro/asmcconv.htm", title: "Conventions" },
                  { url: "intro/asmcintr.htm", title: "What is Adabas Parallel Services?" },
                  { url: "intro/asmcals.htm", title: "Adabas Parallel Services and Adabas Cluster Services" },
                  { url: "intro/asmcuser.htm", title: "Assigning Users" },
                  { url: "intro/asmctask.htm", title: "Cluster Tasks" },
                  { url: "intro/asmcglob.htm", title: "Global Areas" },
                  { url: "intro/asmcmsvc.htm", title: "Global Messaging Services" },
                  { url: "intro/asmcgcmd.htm", title: "Global Commands" },
                  { url: "intro/asmclogs.htm", title: "Logs and Log Merges" },
                  { url: "intro/asmcppt.htm", title: "Parallel Participant Table (PPT)" },
                  { url: "intro/asmcdyna.htm", title: "Dynamic Allocation" },
                  { url: "intro/asmccomp.htm", title: "Components Summary" },
                  { url: "intro/asmcswit.htm", title: "Switching Between Cluster and Noncluster Modes / PLOG Handling" },
                  { url: "intro/asmcsag.htm", title: "Adabas Parallel Services and Other Software AG Products" },
                  { url: "intro/asmcada.htm", title: "Restricted Support for Adabas Features" },
                  { url: "intro/asmcgs.htm", title: "Getting Started" },
              ]
            },
            { url: "op/asmoov.htm", title: "Operations",
              tree: [
                  { url: "op/d0e160.htm", title: "Conventions" },
                  { url: "op/asmoinit.htm", title: "Initialization" },
                  { url: "op/asmoterm.htm", title: "Termination" },
                  { url: "op/alert.htm", title: "Using Alert and Timeout Settings" },
                  { url: "op/collab_cluster_nuclei.htm", title: "Collaboration Between Cluster Nuclei" },
                  { url: "op/asmoback.htm", title: "Backout Processing" },
                  { url: "op/asmorest.htm", title: "Restart/Recovery Processing" },
                  { url: "op/asmoutil.htm", title: "Utility Processing" },
                  { url: "op/asmostat.htm", title: "Cluster Nucleus Session End Statistics" },
                  { url: "op/asmoperf.htm", title: "Performance and Tuning" },
                  { url: "op/smfrecs.htm", title: "Adabas SMF Records" },
                  { url: "op/clusaos.htm", title: "Adabas Online System Cluster Environment Screens" },
              ]
            },
            { url: "ref/amsrov.htm", title: "Reference",
              tree: [
                  { url: "ref/asmrinit.htm", title: "Initialization Parameters" },
                  { url: "ref/adacom.htm", title: "ADACOM Initialization Parameters" },
                  { url: "ref/adanuc.htm", title: "About ADARUN Parameters for Cluster Nuclei" },
                  { url: "ref/adarunrf.htm", title: "Useful ADARUN Parameters for Adabas Parallel Services" },
                  { url: "ref/asmrcmds.htm", title: "Cluster Operator Commands" },
              ]
            },
            { url: "messages/asmmsgs.htm", title: "Messages and Codes" },
            { url: "messages/ADAX.htm", title: "ADAX* - Adabas Cluster Nucleus Messages" },
            { url: "messages/DSP.htm", title: "DSP* - Cluster Data Space (ADADSP) Messages" },
            { url: "messages/PLI.htm", title: "PLI* - ADACOM Initialization Messages" },
            { url: "messages/PLX.htm", title: "PLX* - ADACLU Messages" },
            { url: "messages/nucover.htm", title: "Nucleus Error Messages and Response Codes",
              tree: [
                  { url: "messages/nucstart.htm", title: "Nucleus Startup Error Messages" },
                  { url: "messages/nucresp.htm", title: "Adabas Response Codes" },
                  { url: "messages/abends.htm", title: "User Abend Codes" },
              ]
            },
            { url: "general/glossary.htm", title: "Glossary" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasparallelservices });

==> asm-8.6.1-en-download.zip: asm-8.6.1-en/webhelp/asm-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasparallelservices
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasparallelservices = {
    baseurls: ["../"],
    varname: "adabasparallelservices",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Release Notes",
              tree: [
                  { url: "relnotes/enh.htm", title: "Enhancements" },
                  { url: "relnotes/addons.htm", title: "Adabas Product Support" },
                  { url: "relnotes/restsup.htm", title: "Restricted Support for Adabas Features" },
                  { url: "relnotes/mig_asm.htm", title: "Migrating from Prior Versions" },
                  { url: "relnotes/zaps.htm", title: "Zap Information" },
                  { url: "relnotes/eom.htm", title: "End of Maintenance" },
                  { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
              ]
            },
            { url: "install/asmiov.htm", title: "Installation",
              tree: [
                  { url: "install/asmiconv.htm", title: "Conventions" },
                  { url: "install/sysreq.htm", title: "System Requirements" },
                  { url: "install/asmisma.htm", title: "Using System Maintenance Aid" },
                  { url: "install/asmids.htm", title: "Data Sets Delivered" },
                  { url: "install/asmios.htm", title: "z/OS Systems Installation" },
                  { url: "install/proc_csa.htm", title: "Modifying the z/OS Common Storage (CSA) Key" },
              ]
            },
            { url: "intro/asmcov.htm", title: "Concepts and Facilities",
              tree: [
                  { url: "intro/asmcconv.htm", title: "Conventions" },
                  { url: "intro/asmcintr.htm", title: "What is Adabas Parallel Services?" },
                  { url: "intro/asmcals.htm", title: "Adabas Parallel Services and Adabas Cluster Services" },
                  { url: "intro/asmcuser.htm", title: "Assigning Users" },
                  { url: "intro/asmctask.htm", title: "Cluster Tasks" },
                  { url: "intro/asmcglob.htm", title: "Global Areas" },
                  { url: "intro/asmcmsvc.htm", title: "Global Messaging Services" },
                  { url: "intro/asmcgcmd.htm", title: "Global Commands" },
                  { url: "intro/asmclogs.htm", title: "Logs and Log Merges" },
                  { url: "intro/asmcppt.htm", title: "Parallel Participant Table (PPT)" },
                  { url: "intro/asmcdyna.htm", title: "Dynamic Allocation" },
                  { url: "intro/asmccomp.htm", title: "Components Summary" },
                  { url: "intro/asmcswit.htm", title: "Switching Between Cluster and Noncluster Modes / PLOG Handling" },
                  { url: "intro/asmcsag.htm", title: "Adabas Parallel Services and Other Software GmbH products" },
                  { url: "intro/asmcada.htm", title: "Restricted Support for Adabas Features" },
                  { url: "intro/asmcgs.htm", title: "Getting Started" },
              ]
            },
            { url: "op/asmoov.htm", title: "Operations",
              tree: [
                  { url: "op/d0e160.htm", title: "Conventions" },
                  { url: "op/asmoinit.htm", title: "Initialization" },
                  { url: "op/asmoterm.htm", title: "Termination" },
                  { url: "op/alert.htm", title: "Using Alert and Timeout Settings" },
                  { url: "op/collab_cluster_nuclei.htm", title: "Collaboration Between Cluster Nuclei" },
                  { url: "op/asmoback.htm", title: "Backout Processing" },
                  { url: "op/asmorest.htm", title: "Restart/Recovery Processing" },
                  { url: "op/asmoutil.htm", title: "Utility Processing" },
                  { url: "op/asmostat.htm", title: "Cluster Nucleus Session End Statistics" },
                  { url: "op/asmoperf.htm", title: "Performance and Tuning" },
                  { url: "op/smfrecs.htm", title: "Adabas SMF Records" },
                  { url: "op/clusaos.htm", title: "Adabas Online System Cluster Environment Screens" },
              ]
            },
            { url: "ref/amsrov.htm", title: "Reference",
              tree: [
                  { url: "ref/asmrinit.htm", title: "Initialization Parameters" },
                  { url: "ref/adacom.htm", title: "ADACOM Initialization Parameters" },
                  { url: "ref/adanuc.htm", title: "About ADARUN Parameters for Cluster Nuclei" },
                  { url: "ref/adarunrf.htm", title: "Useful ADARUN Parameters for Adabas Parallel Services" },
                  { url: "ref/asmrcmds.htm", title: "Cluster Operator Commands" },
              ]
            },
            { url: "messages/asmmsgs.htm", title: "Messages and Codes" },
            { url: "messages/ADAX.htm", title: "ADAX* - Adabas Cluster Nucleus Messages" },
            { url: "messages/DSP.htm", title: "DSP* - Cluster Data Space (ADADSP) Messages" },
            { url: "messages/PLI.htm", title: "PLI* - ADACOM Initialization Messages" },
            { url: "messages/PLX.htm", title: "PLX* - ADACLU Messages" },
            { url: "messages/nucover.htm", title: "Nucleus Error Messages and Response Codes",
              tree: [
                  { url: "messages/nucstart.htm", title: "Nucleus Startup Error Messages" },
                  { url: "messages/nucresp.htm", title: "Adabas Response Codes" },
                  { url: "messages/abends.htm", title: "User Abend Codes" },
              ]
            },
            { url: "general/glossary.htm", title: "Glossary" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasparallelservices });
